@@ -1,5 +1,5 @@
 import binascii
-from geoalchemy2.compat import PY3, str as str_
+import struct
 
 try:
     from sqlalchemy.sql import functions
@@ -10,8 +10,11 @@ except ImportError:  # SQLA < 0.9  # pragma: no cover
 from sqlalchemy.types import to_instance
 from sqlalchemy.ext.compiler import compiles
 
+from .compat import PY3, str as str_
+from .exc import ArgumentError
 
-class _SpatialElement(object):
+
+class _SpatialElement(functions.Function):
     """
     The base class for :class:`geoalchemy2.elements.WKTElement` and
     :class:`geoalchemy2.elements.WKBElement`.
@@ -31,18 +34,17 @@ class _SpatialElement(object):
         A boolean indicating whether the extended format (EWKT or EWKB)
         is used. Default is ``False``.
 
-    ``use_st_prefix``
-
-        A boolean indicating whether the ST_ versions of the GeomFromEWKT
-        and GeomFromEWKB functions are used. Default is ``True``.
-
     """
 
-    def __init__(self, data, srid=-1, extended=False, use_st_prefix=True):
+    def __init__(self, data, srid=-1, extended=False):
         self.srid = srid
         self.data = data
         self.extended = extended
-        self.use_st_prefix = use_st_prefix
+        if self.extended:
+            args = [self.geom_from_extended_version, self.data]
+        else:
+            args = [self.geom_from, self.data, self.srid]
+        functions.Function.__init__(self, *args)
 
     def __str__(self):
         return self.desc
@@ -68,23 +70,35 @@ class _SpatialElement(object):
 
     def __getstate__(self):
         state = {
-            'data': str(self),
             'srid': self.srid,
+            'data': str(self),
             'extended': self.extended,
+            'name': self.name,
         }
         return state
 
     def __setstate__(self, state):
-        self.srid = state['srid']
-        self.extended = state['extended']
+        self.__dict__.update(state)
         self.data = self._data_from_desc(state['data'])
+        args = [self.name, self.data]
+        if not self.extended:
+            args.append(self.srid)
+        # we need to call Function.__init__ to properly initialize SQLAlchemy's
+        # internal states
+        functions.Function.__init__(self, *args)
 
     @staticmethod
     def _data_from_desc(desc):
         raise NotImplementedError()
 
 
-class WKTElement(_SpatialElement, functions.Function):
+@compiles(_SpatialElement, 'sqlite')
+def compile_spatialelement(element, compiler, **kw):
+    return "{}({})".format(element.name.lstrip("ST_"),
+                           compiler.process(element.clauses, **kw))
+
+
+class WKTElement(_SpatialElement):
     """
     Instances of this class wrap a WKT or EWKT value.
 
@@ -93,17 +107,25 @@ class WKTElement(_SpatialElement, functions.Function):
         wkt_element_1 = WKTElement('POINT(5 45)')
         wkt_element_2 = WKTElement('POINT(5 45)', srid=4326)
         wkt_element_3 = WKTElement('SRID=4326;POINT(5 45)', extended=True)
-
     """
 
-    def __init__(self, *args, **kwargs):
-        _SpatialElement.__init__(self, *args, **kwargs)
-        if self.extended:
-            f = "ST_GeomFromEWKT" if self.use_st_prefix else "GeomFromEWKT"
-            args = (f, self.data)
-        else:
-            args = ("ST_GeomFromText", self.data, self.srid)
-        functions.Function.__init__(self, *args)
+    geom_from = 'ST_GeomFromText'
+    geom_from_extended_version = 'ST_GeomFromEWKT'
+
+    def __init__(self, data, srid=-1, extended=False):
+        if extended and srid == -1:
+            # read srid from EWKT
+            if not data.startswith('SRID='):
+                raise ArgumentError('invalid EWKT string {}'.format(data))
+            data_s = data.split(';', 1)
+            if len(data_s) != 2:
+                raise ArgumentError('invalid EWKT string {}'.format(data))
+            header = data_s[0]
+            try:
+                srid = int(header[5:])
+            except ValueError:
+                raise ArgumentError('invalid EWKT string {}'.format(data))
+        _SpatialElement.__init__(self, data, srid, extended)
 
     @property
     def desc(self):
@@ -117,7 +139,7 @@ class WKTElement(_SpatialElement, functions.Function):
         return desc
 
 
-class WKBElement(_SpatialElement, functions.Function):
+class WKBElement(_SpatialElement):
     """
     Instances of this class wrap a WKB or EWKB value.
 
@@ -125,18 +147,41 @@ class WKBElement(_SpatialElement, functions.Function):
     type. In most cases you won't need to create ``WKBElement`` instances
     yourself.
 
+    If ``extended`` is ``True`` and ``srid`` is ``-1`` at construction time
+    then the SRID will be read from the EWKB data.
+
     Note: you can create ``WKBElement`` objects from Shapely geometries
     using the :func:`geoalchemy2.shape.from_shape` function.
     """
 
-    def __init__(self, *args, **kwargs):
-        _SpatialElement.__init__(self, *args, **kwargs)
-        if self.extended:
-            f = "ST_GeomFromEWKB" if self.use_st_prefix else "GeomFromEWKB"
-            args = (f, self.data)
-        else:
-            args = ("ST_GeomFromWKB", self.data, self.srid)
-        functions.Function.__init__(self, *args)
+    geom_from = 'ST_GeomFromWKB'
+    geom_from_extended_version = 'ST_GeomFromEWKB'
+
+    def __init__(self, data, srid=-1, extended=False):
+        if extended and srid == -1:
+            # read srid from the EWKB
+            #
+            # WKB struct {
+            #    byte    byteOrder;
+            #    uint32  wkbType;
+            #    uint32  SRID;
+            #    struct  geometry;
+            # }
+            # byteOrder enum {
+            #     WKB_XDR = 0,  // Most Significant Byte First
+            #     WKB_NDR = 1,  // Least Significant Byte First
+            # }
+            if isinstance(data, str_):
+                # SpatiaLite case
+                # assume that the string is an hex value
+                header = binascii.unhexlify(data[:18])
+            else:
+                header = data[:9]
+            if not PY3:
+                header = bytearray(header)
+            byte_order, srid = header[0], header[5:]
+            srid = struct.unpack('<I' if byte_order else '>I', srid)[0]
+        _SpatialElement.__init__(self, data, srid, extended)
 
     @property
     def desc(self):
@@ -144,6 +189,7 @@ class WKBElement(_SpatialElement, functions.Function):
         This element's description string.
         """
         if isinstance(self.data, str_):
+            # SpatiaLite case
             return self.data
         desc = binascii.hexlify(self.data)
         if PY3:
