@@ -1,12 +1,14 @@
 import re
 import pytest
 
+from shapely import wkb
 from sqlalchemy import Table, MetaData, Column, String, func
 from geoalchemy2.types import Geometry
 from geoalchemy2.elements import (
     WKTElement, WKBElement, RasterElement, CompositeElement
 )
-from geoalchemy2.compat import str as str_
+from geoalchemy2.compat import buffer as buffer_, bytes as bytes_, str as str_
+from geoalchemy2.exc import ArgumentError
 
 
 @pytest.fixture
@@ -46,25 +48,74 @@ class TestWKTElement():
         assert unpickled.srid == 3
         assert unpickled.extended is True
         assert unpickled.data == 'POINT(1 2)'
+        assert unpickled.name == 'ST_GeomFromEWKT'
+        f = unpickled.ST_Buffer(2)
+        eq_sql(f, 'ST_Buffer('
+               'ST_GeomFromEWKT(:ST_GeomFromEWKT_1), '
+               ':ST_Buffer_1)')
+        assert f.compile().params == {
+            u'ST_Buffer_1': 2,
+            u'ST_GeomFromEWKT_1': 'POINT(1 2)',
+        }
 
 
 class TestExtendedWKTElement():
 
+    _srid = 3857  # expected srid
+    _wkt = 'POINT (1 2 3)'  # expected wkt
+    _ewkt = 'SRID=3857;POINT (1 2 3)'  # expected ewkt
+
     def test_desc(self):
-        e = WKTElement('SRID=3857;POINT(1 2 3)', extended=True)
-        assert e.desc == 'SRID=3857;POINT(1 2 3)'
+        e = WKTElement(self._ewkt, extended=True)
+        assert e.desc == self._ewkt
 
     def test_function_call(self):
-        e = WKTElement('SRID=3857;POINT(1 2 3)', extended=True)
+        e = WKTElement(self._ewkt, extended=True)
         f = e.ST_Buffer(2)
         eq_sql(f, 'ST_Buffer('
                'ST_GeomFromEWKT(:ST_GeomFromEWKT_1), '
                ':ST_Buffer_1)')
         assert f.compile().params == {
             u'ST_Buffer_1': 2,
-            u'ST_GeomFromEWKT_1': 'SRID=3857;POINT(1 2 3)'
+            u'ST_GeomFromEWKT_1': self._ewkt
         }
 
+    def test_pickle_unpickle(self):
+        import pickle
+        e = WKTElement(self._ewkt, extended=True)
+        pickled = pickle.dumps(e)
+        unpickled = pickle.loads(pickled)
+        assert unpickled.srid == self._srid
+        assert unpickled.extended is True
+        assert unpickled.data == self._ewkt
+        assert unpickled.name == 'ST_GeomFromEWKT'
+        f = unpickled.ST_Buffer(2)
+        eq_sql(f, 'ST_Buffer('
+               'ST_GeomFromEWKT(:ST_GeomFromEWKT_1), '
+               ':ST_Buffer_1)')
+        assert f.compile().params == {
+            u'ST_Buffer_1': 2,
+            u'ST_GeomFromEWKT_1': self._ewkt,
+        }
+
+    def test_unpack_srid_from_ewkt(self):
+        """
+        Unpack SRID from WKT struct (when it is not provided as arg)
+        to ensure geometry result processor preserves query SRID.
+        """
+        e = WKTElement(self._ewkt, extended=True)
+        assert e.srid == self._srid
+        assert e.desc == self._ewkt
+
+    def test_unpack_srid_from_ewkt_forcing_srid(self):
+        e = WKTElement(self._ewkt, srid=9999, extended=True)
+        assert e.srid == 9999
+        assert e.desc == self._ewkt
+
+    def test_unpack_srid_from_bad_ewkt(self):
+        with pytest.raises(ArgumentError):
+            WKTElement('SRID=BAD SRID;POINT (1 2 3)', extended=True)
+
 
 class TestWKTElementFunction():
 
@@ -119,42 +170,78 @@ class TestExtendedWKTElementFunction():
         }
 
 
-class TestWKBElement():
+class TestExtendedWKBElement():
+
+    # _bin/_hex computed by following query:
+    # SELECT ST_GeomFromEWKT('SRID=3;POINT(1 2)');
+    _bin = buffer_(b'\x01\x01\x00\x00 \x03\x00\x00\x00\x00\x00\x00'
+                   b'\x00\x00\x00\xf0?\x00\x00\x00\x00\x00\x00\x00@')
+    _hex = str_('010100002003000000000000000000f03f0000000000000040')
+    _srid = 3  # expected srid
+    _wkt = 'POINT (1 2)'  # expected wkt
 
     def test_desc(self):
-        e = WKBElement(b'\x01\x02', extended=True)
-        assert e.desc == '0102'
+        e = WKBElement(self._bin, extended=True)
+        assert e.desc == self._hex
 
     def test_desc_str(self):
-        e = WKBElement(str_('0102'))
-        assert e.desc == str_('0102')
+        e = WKBElement(self._hex)
+        assert e.desc == self._hex
 
     def test_function_call(self):
-        e = WKBElement(b'\x01\x02', extended=True)
+        e = WKBElement(self._bin, extended=True)
         f = e.ST_Buffer(2)
         eq_sql(f, 'ST_Buffer('
                'ST_GeomFromEWKB(:ST_GeomFromEWKB_1), '
                ':ST_Buffer_1)')
         assert f.compile().params == {
             u'ST_Buffer_1': 2,
-            u'ST_GeomFromEWKB_1': b'\x01\x02',
+            u'ST_GeomFromEWKB_1': self._bin,
         }
 
     def test_function_str(self):
-        e = WKBElement(b'\x01\x02', extended=True)
+        e = WKBElement(self._bin, extended=True)
         assert isinstance(str(e), str)
 
     def test_pickle_unpickle(self):
         import pickle
-        e = WKBElement(b'\x01\x02', srid=3, extended=True)
+        e = WKBElement(self._bin, srid=self._srid, extended=True)
         pickled = pickle.dumps(e)
         unpickled = pickle.loads(pickled)
-        assert unpickled.srid == 3
+        assert unpickled.srid == self._srid
         assert unpickled.extended is True
-        assert unpickled.data == b'\x01\x02'
+        assert unpickled.data == bytes_(self._bin)
+        assert unpickled.name == 'ST_GeomFromEWKB'
+        f = unpickled.ST_Buffer(2)
+        eq_sql(f, 'ST_Buffer('
+               'ST_GeomFromEWKB(:ST_GeomFromEWKB_1), '
+               ':ST_Buffer_1)')
+        assert f.compile().params == {
+            u'ST_Buffer_1': 2,
+            u'ST_GeomFromEWKB_1': bytes_(self._bin),
+        }
+
+    def test_unpack_srid_from_bin(self):
+        """
+        Unpack SRID from WKB struct (when it is not provided as arg)
+        to ensure geometry result processor preserves query SRID.
+        """
+        e = WKBElement(self._bin, extended=True)
+        assert e.srid == self._srid
+        assert wkb.loads(bytes_(e.data)).wkt == self._wkt
+
+    def test_unpack_srid_from_bin_forcing_srid(self):
+        e = WKBElement(self._bin, srid=9999, extended=True)
+        assert e.srid == 9999
+        assert wkb.loads(bytes_(e.data)).wkt == self._wkt
+
+    def test_unpack_srid_from_hex(self):
+        e = WKBElement(self._hex, extended=True)
+        assert e.srid == self._srid
+        assert wkb.loads(e.data, hex=True).wkt == self._wkt
 
 
-class TestExtendedWKBElement():
+class TestWKBElement():
 
     def test_desc(self):
         e = WKBElement(b'\x01\x02')
