@@ -1,3 +1,4 @@
+from pkg_resources import parse_version
 import pytest
 
 try:
@@ -8,6 +9,7 @@ else:
     compat.register()
     del compat
 
+from sqlalchemy import __version__ as SA_VERSION
 from sqlalchemy import create_engine, Table, MetaData, Column, Integer, bindparam
 from sqlalchemy.orm import sessionmaker
 from sqlalchemy.ext.declarative import declarative_base
@@ -59,6 +61,21 @@ class Summit(Base):
         self.geom = geom
 
 
+class IndexTestWithSchema(Base):
+    __tablename__ = 'indextestwithschema'
+    __table_args__ = {'schema': 'gis'}
+    id = Column(Integer, primary_key=True)
+    geom1 = Column(Geometry(geometry_type='POINT', srid=4326))
+    geom2 = Column(Geometry(geometry_type='POINT', srid=4326, management=True))
+
+
+class IndexTestWithoutSchema(Base):
+    __tablename__ = 'indextestwithoutschema'
+    id = Column(Integer, primary_key=True)
+    geom1 = Column(Geometry(geometry_type='POINT', srid=4326))
+    geom2 = Column(Geometry(geometry_type='POINT', srid=4326, management=True))
+
+
 session = sessionmaker(bind=engine)()
 
 postgis_version = session.execute(func.postgis_version()).scalar()
@@ -96,16 +113,23 @@ class TestIndex():
         session.rollback()
         metadata.drop_all()
 
-    def test_LakeIndex(self):
-        """ Make sure the Lake table has an index on the geom column """
-
+    def test_index_with_schema(self):
         inspector = reflection.Inspector.from_engine(engine)
-        indices = inspector.get_indexes(Lake.__tablename__, schema='gis')
-        assert len(indices) == 1
+        indices = inspector.get_indexes(IndexTestWithSchema.__tablename__, schema='gis')
+        assert len(indices) == 2
+        assert not indices[0].get('unique')
+        assert indices[0].get('column_names')[0] in (u'geom1', u'geom2')
+        assert not indices[1].get('unique')
+        assert indices[1].get('column_names')[0] in (u'geom1', u'geom2')
 
-        index = indices[0]
-        assert not index.get('unique')
-        assert index.get('column_names') == [u'geom']
+    def test_index_without_schema(self):
+        inspector = reflection.Inspector.from_engine(engine)
+        indices = inspector.get_indexes(IndexTestWithSchema.__tablename__)
+        assert len(indices) == 2
+        assert not indices[0].get('unique')
+        assert indices[0].get('column_names')[0] in (u'geom1', u'geom2')
+        assert not indices[1].get('unique')
+        assert indices[1].get('column_names')[0] in (u'geom1', u'geom2')
 
 
 class TestTypMod():
@@ -489,6 +513,40 @@ class TestCallFunction():
                 type_coerce('POINT(5 45)', Geography)) < 1000).one()
         assert poi.id == poi_id
 
+    @pytest.mark.skipif(
+        parse_version(SA_VERSION) < parse_version("1.3.4"),
+        reason='Case-insensitivity is only available for sqlalchemy>=1.3.4')
+    def test_comparator_case_insensitivity(self):
+        lake_id = self._create_one_lake()
+
+        s = select([func.ST_Buffer(Lake.__table__.c.geom, 2)])
+        r1 = session.execute(s).scalar()
+        assert isinstance(r1, WKBElement)
+
+        lake = session.query(Lake).get(lake_id)
+
+        r2 = session.execute(lake.geom.ST_Buffer(2)).scalar()
+        assert isinstance(r2, WKBElement)
+
+        r3 = session.execute(lake.geom.st_buffer(2)).scalar()
+        assert isinstance(r3, WKBElement)
+
+        r4 = session.execute(lake.geom.St_BuFfEr(2)).scalar()
+        assert isinstance(r4, WKBElement)
+
+        r5 = session.query(Lake.geom.ST_Buffer(2)).scalar()
+        assert isinstance(r5, WKBElement)
+
+        r6 = session.query(Lake.geom.st_buffer(2)).scalar()
+        assert isinstance(r6, WKBElement)
+
+        r7 = session.query(Lake.geom.St_BuFfEr(2)).scalar()
+        assert isinstance(r7, WKBElement)
+
+        assert (
+            r1.data == r2.data == r3.data == r4.data == r5.data == r6.data
+            == r7.data)
+
 
 class TestReflection():
 
