@@ -1,4 +1,4 @@
-from geoalchemy2.compat import buffer, bytes
+from geoalchemy2.compat import buffer, bytes, str
 from geoalchemy2.elements import WKBElement, WKTElement
 from geoalchemy2.shape import from_shape, to_shape
 
@@ -16,6 +16,15 @@ def test_to_shape_WKBElement():
     assert s.y == 2
 
 
+def test_to_shape_WKBElement_str():
+    # POINT(1 2)
+    e = WKBElement(str('0101000000000000000000f03f0000000000000040'))
+    s = to_shape(e)
+    assert isinstance(s, Point)
+    assert s.x == 1
+    assert s.y == 2
+
+
 def test_to_shape_ExtendedWKBElement():
     # SRID=3857;POINT(1 2 3)
     e = WKBElement(b'\x01\x01\x00\x00\xa0\x11\x0f\x00\x00\x00'
